@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.402 2013/09/23 22:15:53 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.411 2013/10/16 17:11:09 zender Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
@@ -160,6 +160,8 @@ extern "C" {
   char *prg_nm_get(void);
   int prg_get(void);
   unsigned short dbg_lvl_get(void);
+  unsigned short nco_hdf_cnv_get(void);
+  unsigned short nco_mrd_cnv_get(void);
   unsigned short nco_rth_cnv_get(void);
   unsigned short nco_upk_cnv_get(void);
 
@@ -176,6 +178,12 @@ extern "C" {
   unsigned short dbg_lvl=0; /* [enm] Debugging level */
   unsigned short dbg_lvl_get(void){return dbg_lvl;} /* [enm] Debugging level */
 
+  unsigned short nco_hdf_cnv=0; /* [enm] HDF convention */
+  unsigned short nco_hdf_cnv_get(void){return nco_hdf_cnv;} /* [enm] HDF convention */
+
+  unsigned short nco_mrd_cnv=0; /* [enm] Multiple Record Dimension convention */
+  unsigned short nco_mrd_cnv_get(void){return nco_mrd_cnv;} /* [enm] Multiple Record Dimension convention */
+
   unsigned short nco_rth_cnv=1; /* [enm] Arithmetic convention */
   unsigned short nco_rth_cnv_get(void){return nco_rth_cnv;} /* [enm] Arithmetic convention */
 
@@ -350,6 +358,7 @@ extern "C" {
     ncatted,
     ncbo,
     ncea,
+    ncga,
     ncecat,
     ncflint,
     ncks,
@@ -413,18 +422,32 @@ extern "C" {
     nco_obj_typ_nonatomic_var /*  2, Variable of non-atomic type (vlen, opaque, enum, compound, user-defined) */
   } nco_obj_typ;
   
-  enum nco_upk_cnv{ /* [enm] Unpacking convention to assume */
-    /* netCDF convention: http://www.unidata.ucar.edu/software/netcdf/docs/netcdf/Attribute-Conventions.html
-       NASA convention :  http://modis-atmos.gsfc.nasa.gov/MOD08_D3/faq.html */
-    nco_upk_netCDF, /* 0 netCDF unpack convention: unpacked=(scale_factor*packed)+add_offset */
-    nco_upk_HDF     /* 1 HDF unpack convention:    unpacked=scale_factor*(packed-add_offset) */
-  }; /* end nco_upk_cnv */
+  enum nco_hdf_cnv{ /* [enm] HDF convention */
+    /* This currently could be implemented as a flag rather than an enum
+       General case may need more than binary option so use enum */
+    nco_hdf_nil, /* 0 No special treatment */
+    nco_hdf4 /* 1 Treat file as HDF4 */
+  }; /* end nco_hdf_cnv */
+
+  enum nco_mrd_cnv{ /* [enm] Multiple Record Dimension convention: for ncecat and ncpdq */
+    /* This currently could be implemented as a flag rather than an enum
+       General case may need more than binary option so use enum */
+    nco_mrd_restrict, /* 0 Fix some dimensions so as to avoid producing additional record dimensions */
+    nco_mrd_allow  /* 1 Allow multiple record dimensions when operator produces them naturally */
+  }; /* end nco_mrd_cnv */
 
   enum nco_rth_cnv{ /* [enm] Arithmetic convention to assume */
     nco_rth_flt_flt, /* 0 Keep single-precision floating point (default and NCO historical norm) */
     nco_rth_flt_dbl  /* 1 Promote single-precision floating point to double before arithmetic */
   }; /* end nco_rth_cnv */
 
+  enum nco_upk_cnv{ /* [enm] Unpacking convention to assume */
+    /* netCDF convention  : http://www.unidata.ucar.edu/software/netcdf/docs/netcdf/Attribute-Conventions.html
+       HDF/NASA convention: http://modis-atmos.gsfc.nasa.gov/MOD08_D3/faq.html */
+    nco_upk_netCDF, /* 0 netCDF unpack convention: unpacked=(scale_factor*packed)+add_offset */
+    nco_upk_HDF     /* 1 HDF unpack convention:    unpacked=scale_factor*(packed-add_offset) */
+  }; /* end nco_upk_cnv */
+
   typedef enum aed{ /* [enm] Attribute editor mode */
     aed_append,
     aed_create,
@@ -642,6 +665,7 @@ extern "C" {
     md5_sct *md5; /* [flg] MD5 configuration */
     nco_bool cdl; /* [flg] Print valid CDL */
     nco_bool xml; /* [flg] Print valid XML (NcML) */
+    nco_bool xml_lcn; /* [flg] Print XML location tag */
     nco_bool trd; /* [flg] Print traditional NCO format */
     nco_bool nfo_cdl; /* [flg] Print extra information in CDL mode */
     nco_bool new_fmt; /* [flg] Print in new format */
