@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.384 2013/09/27 05:16:35 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.391 2013/10/16 06:54:17 pvicente Exp $ */
 
 /* Purpose: Group utilities */
 
@@ -622,14 +622,6 @@ nco_skp_var                          /* [fnc] Skip variable while doing record
  const char * const rec_nm_fll,      /* I [sng] Full name of record being done in loop (trv_tbl->lmt_rec[idx_rec]->nm_fll ) */
  const trv_tbl_sct * const trv_tbl); /* I [sct] Traversal table */
 
-
-var_sct *                             /* O [sct] Variable */  
-nco_var_get_trv                       /* [fnc] Fill-in variable structure for a variable named "var_nm" */
-(const int nc_id,                     /* I [id] netCDF file ID */
- const char * const var_nm,           /* I [sng] Variable name (relative) */
- const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
-
-
 var_sct *                             /* O [sct] Variable (weight) */  
 nco_var_get_wgt_trv                   /* [fnc] Retrieve weighting or mask variable */
 (const int nc_id,                     /* I [id] netCDF file ID */
@@ -637,6 +629,18 @@ nco_var_get_wgt_trv                   /* [fnc] Retrieve weighting or mask variab
  const var_sct * const var,           /* I [sct] Variable that needs the weight/mask variable */
  const trv_tbl_sct * const trv_tbl);  /* I [lst] Traversal table */
 
+dmn_trv_sct *                         /* O [sct] Table dimension object */
+nco_dmn_usr_sng                       /* [fnc] Parse input string and return table dimension object */
+(const char * const usr_sng,          /* I [sng] Object name */
+ const trv_tbl_sct * const trv_tbl,   /* I [lst] Traversal table */ 
+ nco_bool *is_opt);                   /* O [flg] Dimension presence is optional (name has '.') */       
+    
+trv_sct *                             /* O [sct] Table object */
+nco_obj_usr_sng                       /* [fnc] Parse input string and return table object */
+(const char * const usr_sng,          /* I [sng] Object name */
+ const trv_tbl_sct * const trv_tbl,   /* I [lst] Traversal table */ 
+ nco_bool *is_opt);                   /* O [flg] Dimension presence is optional (input string has '.') */
+
 
 #ifdef __cplusplus
 } /* end extern "C" */
