@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_lmt.h,v 1.45 2012/01/01 20:51:53 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_lmt.h,v 1.66 2013/06/08 06:31:40 zender Exp $ */
 
 /* Purpose: Hyperslab limits */
 
-/* Copyright (C) 1995--2012 Charlie Zender
+/* Copyright (C) 1995--2013 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -20,7 +20,10 @@
 #include <math.h> /* sin cos cos sin 3.14159 */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 #include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
-#include <string.h> /* strcmp. . . */
+#include <string.h> /* strcmp() */
+#ifdef HAVE_STRINGS_H
+# include <strings.h> /* strcasecmp() */
+#endif /* !HAVE_STRINGS_H */
 
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
@@ -44,7 +47,20 @@ enum lmt_typ{ /* [enm] Limit type */
  lmt_dmn_idx, /* 1, Dimension index limit */
  lmt_udu_sng /* 2, UDUnits string */
 }; /* end lmt_typ enum */
-  
+
+void
+nco_lmt_init /* [fnc] Initialize limit to NULL/default values */
+(lmt_sct *lmt); /* I/O [sct] Limit structure to initialize */
+
+void
+nco_lmt_prt /* [fnc] Print a Limit structure */
+(lmt_sct *lmt); /* I/O [sct] Limit structure to print */
+
+void
+nco_lmt_cpy /* [fnc] Deep-copy a Limit structure */
+(const lmt_sct * const lmt1, /* I [sct] Limit structure to copy */
+ lmt_sct *lmt2);/* O [sct] New limit structure */
+
 void
 nco_lmt_evl /* [fnc] Parse user-specified limits into hyperslab specifications */
 (int nc_id, /* I [idx] netCDF file ID */
@@ -67,13 +83,13 @@ nco_lmt_lst_free /* [fnc] Free memory associated with limit structure list */
 (lmt_sct **lmt_lst, /* I/O [sct] Limit structure list to free */
  const int lmt_nbr); /* I [nbr] Number of limit structures in list */
 
-lmt_all_sct * /* O [sct] Pointer to free'd structure */
+lmt_msa_sct * /* O [sct] Pointer to free'd structure */
 nco_lmt_all_free /* [fnc] Free memory associated with lmt_all structure */
-(lmt_all_sct *lmt_all); /* I/O [sct] Limit structure to free */
+(lmt_msa_sct *lmt_all); /* I/O [sct] Limit structure to free */
 
-lmt_all_sct ** /* O [sct] Pointer to free'd structure list */
+lmt_msa_sct ** /* O [sct] Pointer to free'd structure list */
 nco_lmt_all_lst_free /* [fnc] Free memory associated with lmt_all structure list */
-(lmt_all_sct **lmt_all_lst, /* I/O [sct] Limit structure list to free */
+(lmt_msa_sct **lmt_all_lst, /* I/O [sct] Limit structure list to free */
  const int lmt_all_nbr); /* I [nbr] Number of limit structures in list */
 
 lmt_sct ** /* O [sct] Structure list with user-specified strings for min and max limits */
@@ -93,6 +109,33 @@ int /* O [enm] Limit type */
 nco_lmt_typ /* [fnc] Determine limit type */
 (char *sng);/* I [ptr] Pointer to limit string */
 
+void
+nco_prt_lmt                    /* [fnc] Print limit information */
+(lmt_sct lmt,                  /* I [sct] Limit structure */
+ int min_lmt_typ,              /* I [nbr] Limit type */
+ nco_bool FORTRAN_IDX_CNV,     /* I [flg] Hyperslab indices obey Fortran convention */
+ nco_bool flg_no_data_ok,      /* I [flg] True if file contains no data for hyperslab */
+ long rec_usd_cml,             /* I [nbr] Number of valid records already processed (only used for record dimensions in multi-file operators) */
+ monotonic_direction_enm monotonic_direction, /* I [enm] Monotonic_direction */
+ nco_bool rec_dmn_and_mfo,     /* I [flg] True if record dimension in multi-file operator */
+ long cnt_rmn_ttl,             /* I [nbr] Total records to be read from this and all remaining files */
+ long cnt_rmn_crr,             /* I [nbr] Records to extract from current file */
+ long rec_skp_vld_prv_dgn);    /* I [nbr] Records skipped at end of previous valid file, if any (diagnostic only) */
+
+void                      
+nco_lmt_evl_dmn_crd            /* [fnc] Parse user-specified limits into hyperslab specifications */
+(const int nc_id,              /* I [ID] netCDF file ID */
+ long rec_usd_cml,             /* I [nbr] Number of valid records already processed (only used for record dimensions in multi-file operators) */
+ nco_bool FORTRAN_IDX_CNV,     /* I [flg] Hyperslab indices obey Fortran convention */
+ const char * const grp_nm_fll,/* I [sng] Full group name (dimension or coordinate) */
+ const char * const nm,        /* I [sng] Name (dimension or coordinate) */
+ const size_t sz,              /* I [nbr] Size (dimension or coordinate) */
+ const nco_bool is_rec,        /* I [flg] Is a record (dimension or coordinate) ? */
+ const nco_bool is_crd,        /* I [flg] Is a coordinate variable ? */
+ lmt_sct *lmt_ptr);            /* I/O [sct] Structure from nco_lmt_prs() in input, filled on output  */
+ 
+
+
 
 #ifdef __cplusplus
 } /* end extern "C" */
