@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_prn.c,v 1.164 2013/09/17 00:48:27 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_prn.c,v 1.173 2013/10/16 17:11:09 zender Exp $ */
 
 /* Purpose: Print variables, attributes, metadata */
 
@@ -24,7 +24,10 @@ nco_prn_att /* [fnc] Print all attributes of single variable or group */
   const char spc_sng[]=""; /* [sng] Space string */
   const char cma_sng[]=", "; /* [sng] Comma string */
 
+  char *nm_cdl;
   char *sng_val_sng; /* [sng] String of NC_CHAR */
+  char *sng_val_sng_cpy; /* [sng] Copy of sng_val_sng to avoid cppcheck error about using sng_val_sng as both parameter and desitnation in sprintf(). NB: free() only one of these two pointers. */
+
   char att_sng_dlm[NCO_MAX_LEN_FMT_SNG];
   char att_sng_pln[NCO_MAX_LEN_FMT_SNG];
   char chr_val; /* [sng] Current character */
@@ -84,7 +87,11 @@ nco_prn_att /* [fnc] Print all attributes of single variable or group */
     att[idx].val.vp=(void *)nco_malloc(att_sz*nco_typ_lng(att[idx].type));
     (void)nco_get_att(grp_id,var_id,att[idx].nm,att[idx].val.vp,att[idx].type);
     
-    if(prn_flg->cdl) (void)fprintf(stdout,"%*s%s%s:%s = ",prn_ndn,spc_sng,(att[idx].type == NC_STRING) ? "string " : "",src_sng,att[idx].nm); 
+    if(prn_flg->cdl){
+      nm_cdl=nm2sng_cdl(att[idx].nm);
+      (void)fprintf(stdout,"%*s%s%s:%s = ",prn_ndn,spc_sng,(att[idx].type == NC_STRING) ? "string " : "",src_sng,nm_cdl); 
+      nm_cdl=(char *)nco_free(nm_cdl);
+    } /* !cdl */
     if(prn_flg->trd) (void)fprintf(stdout,"%*s%s attribute %i: %s, size = %li %s, value = ",prn_ndn,spc_sng,src_sng,idx,att[idx].nm,att_sz,nco_typ_sng(att[idx].type));
     if(prn_flg->xml) (void)fprintf(stdout,"%*s<attribute name=\"%s\" value=\"",prn_ndn,spc_sng,att[idx].nm); 
     
@@ -133,7 +140,7 @@ nco_prn_att /* [fnc] Print all attributes of single variable or group */
 	    sng_lng=att_sz;
 	    sng_lngm1=sng_lng-1UL;
 	    /* Worst case is printable strings are six or four times longer than unformatted, i.e., '\"' == "&quot;" or '\\' == "\\\\" */
-	    sng_val_sng=(char *)nco_malloc(6*sng_lng+1UL);
+	    sng_val_sng_cpy=sng_val_sng=(char *)nco_malloc(6*sng_lng+1UL);
 	  } /* endif first element of string array */
 	  /* New string begins each element where penultimate dimension changes */
 	  if(lmn%sng_lng == 0L){
@@ -141,7 +148,7 @@ nco_prn_att /* [fnc] Print all attributes of single variable or group */
 	    sng_val_sng[0]='\0';
 	  } /* endif new string */
 	  (void)strcat(sng_val_sng,(prn_flg->cdl) ? chr2sng_cdl(chr_val,val_sng) : chr2sng_xml(chr_val,val_sng));
-	  if(chr_val == '\n' && lmn != att_szm1 && prn_flg->cdl) (void)sprintf(sng_val_sng,"%s\",\n%*s\"",sng_val_sng,prn_ndn+prn_flg->var_fst,spc_sng);
+	  if(chr_val == '\n' && lmn != att_szm1 && prn_flg->cdl) (void)sprintf(sng_val_sng,"%s\",\n%*s\"",sng_val_sng_cpy,prn_ndn+prn_flg->var_fst,spc_sng);
 	  if(lmn%sng_lng == sng_lngm1){
 	    (void)fprintf(stdout,"%s%s",sng_val_sng,(prn_flg->xml) ? "" : "\"");
 	    /* Print commas after non-final strings */
@@ -340,7 +347,8 @@ nco_typ_fmt_sng_att_xml /* [fnc] Provide sprintf() format string for specified a
      Unidata formats shown in ncdump.c near line 459
      Float formats called float_att_fmt, double_att_fmt are in dumplib.c,
      and are user-configurable with -p float_digits,double_digits.
-     These default to 7 and 15, respectively. */
+     These default to 7 and 15, respectively
+     Use these formats for XML attributes AND variables because distinct formats for XML variables, if any, are not known (because ncdump does not dump XML variable values */
 
   static const char fmt_NC_FLOAT[]="%#.7g"; /* %g defaults to 6 digits of precision */
   static const char fmt_NC_DOUBLE[]="%#.15g"; /* %g defaults to 6 digits of precision */
@@ -890,6 +898,8 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
   char dmn_sng[200];
   char sng_foo[200];
 
+  char *nm_cdl;
+
   int deflate; /* [flg] Deflation is on */
   int dfl_lvl; /* [enm] Deflate level [0..9] */
   int dmn_idx;
@@ -921,8 +931,10 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
   (void)nco_inq_var(grp_id,var_id,(char *)NULL,&var_typ,&nbr_dim,(int *)NULL,&nbr_att);
 
   /* Storage properties */
-  (void)nco_inq_var_chunking(grp_id,var_id,&srg_typ,cnk_sz);
-  (void)nco_inq_var_deflate(grp_id,var_id,&shuffle,&deflate,&dfl_lvl);
+  if(nco_hdf_cnv_get() != nco_hdf4){
+    (void)nco_inq_var_chunking(grp_id,var_id,&srg_typ,cnk_sz);
+    (void)nco_inq_var_deflate(grp_id,var_id,&shuffle,&deflate,&dfl_lvl);
+  } /* endif */
   (void)nco_inq_var_packing(grp_id,var_id,&packing);
 
   /* Loop over dimensions */
@@ -956,7 +968,8 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
 
   /* Print header for variable */
   if(prn_flg->new_fmt) prn_ndn=prn_flg->sxn_fst+prn_flg->var_fst+var_trv->grp_dpt*prn_flg->spc_per_lvl;
-  if(prn_flg->trd) (void)fprintf(stdout,"%*s%s: type %s, %i dimension%s, %i attribute%s, chunked? %s, compressed? %s, packed? %s\n",prn_ndn,spc_sng,var_trv->nm,nco_typ_sng(var_typ),nbr_dim,(nbr_dim == 1) ? "" : "s",nbr_att,(nbr_att == 1) ? "" : "s",(srg_typ == NC_CHUNKED) ? "yes" : "no",(deflate) ? "yes" : "no",(packing) ? "yes" : "no");
+  if(prn_flg->trd && (nco_hdf_cnv_get() == nco_hdf4)) (void)fprintf(stdout,"%*s%s: type %s, %i dimension%s, %i attribute%s, chunked? HDF4_UNKNOWN, compressed? HDF4_UNKNOWN, packed? %s\n",prn_ndn,spc_sng,var_trv->nm,nco_typ_sng(var_typ),nbr_dim,(nbr_dim == 1) ? "" : "s",nbr_att,(nbr_att == 1) ? "" : "s",(packing) ? "yes" : "no");
+  if(prn_flg->trd && (nco_hdf_cnv_get() != nco_hdf4)) (void)fprintf(stdout,"%*s%s: type %s, %i dimension%s, %i attribute%s, chunked? %s, compressed? %s, packed? %s\n",prn_ndn,spc_sng,var_trv->nm,nco_typ_sng(var_typ),nbr_dim,(nbr_dim == 1) ? "" : "s",nbr_att,(nbr_att == 1) ? "" : "s",(srg_typ == NC_CHUNKED) ? "yes" : "no",(deflate) ? "yes" : "no",(packing) ? "yes" : "no");
   if(prn_flg->xml) (void)fprintf(stdout,"%*s<variable name=\"%s\" type=\"%s\"",prn_ndn,spc_sng,var_trv->nm,cdl_typ_nm(var_typ));
 
   /* Print type, shape, and total size of variable */
@@ -965,7 +978,13 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
     if(prn_flg->trd) (void)fprintf(stdout,"%*s%s size (RAM) = %ld*sizeof(%s) = %ld*%lu = %lu bytes\n",prn_ndn,spc_sng,var_trv->nm,var_sz,nco_typ_sng(var_typ),var_sz,(unsigned long)nco_typ_lng(var_typ),(unsigned long)(var_sz*nco_typ_lng(var_typ)));
   }else{
     for(dmn_idx=0;dmn_idx<nbr_dim;dmn_idx++){
-      if(prn_flg->xml) (void)sprintf(sng_foo,"%s%s%s",(dmn_idx == 0) ? " shape=\"" : "",var_trv->var_dmn[dmn_idx].dmn_nm,(dmn_idx < nbr_dim-1) ? " " : "\""); else (void)sprintf(sng_foo,"%s%s%s",(dmn_idx == 0) ? "(" : "",var_trv->var_dmn[dmn_idx].dmn_nm,(dmn_idx < nbr_dim-1) ? "," : ")");
+      if(prn_flg->xml){
+	(void)sprintf(sng_foo,"%s%s%s",(dmn_idx == 0) ? " shape=\"" : "",var_trv->var_dmn[dmn_idx].dmn_nm,(dmn_idx < nbr_dim-1) ? " " : "\""); 
+      }else{
+	nm_cdl=nm2sng_cdl(var_trv->var_dmn[dmn_idx].dmn_nm);
+	(void)sprintf(sng_foo,"%s%s%s",(dmn_idx == 0) ? "(" : "",nm_cdl,(dmn_idx < nbr_dim-1) ? "," : ")");
+	nm_cdl=(char *)nco_free(nm_cdl);
+      } /* !xml */
       (void)strcat(dmn_sng,sng_foo);
     } /* end loop over dim */
 
@@ -978,15 +997,20 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
     (void)strcat(sz_sng,sng_foo);
 
     for(dmn_idx=0;dmn_idx<nbr_dim;dmn_idx++) var_sz*=dmn_sz[dmn_idx];
-    (void)nco_inq_var_deflate(grp_id,var_id,&shuffle,&deflate,&dfl_lvl);
+    if(nco_hdf_cnv_get() != nco_hdf4) (void)nco_inq_var_deflate(grp_id,var_id,&shuffle,&deflate,&dfl_lvl);
 
     if(prn_flg->trd){
-      if(deflate) (void)fprintf(stdout,"%*s%s compression (Lempel-Ziv %s shuffling) level = %d\n",prn_ndn,spc_sng,var_trv->nm,(shuffle) ? "with" : "without",dfl_lvl);
+      if((nco_hdf_cnv_get() != nco_hdf4) && deflate) (void)fprintf(stdout,"%*s%s compression (Lempel-Ziv %s shuffling) level = %d\n",prn_ndn,spc_sng,var_trv->nm,(shuffle) ? "with" : "without",dfl_lvl);
+      if(nco_hdf_cnv_get() == nco_hdf4) (void)fprintf(stdout,"%*s%s compression and shuffling characteristics are HDF4_UNKNOWN\n",prn_ndn,spc_sng,var_trv->nm);
       (void)fprintf(stdout,"%*s%s size (RAM) = %s = %li*%lu = %lu bytes\n",prn_ndn,spc_sng,var_trv->nm,sz_sng,var_sz,(unsigned long)nco_typ_lng(var_typ),(unsigned long)(var_sz*nco_typ_lng(var_typ)));
     } /* !prn_flg->trd */
 
   } /* end if variable is scalar */
-  if(prn_flg->cdl) (void)fprintf(stdout,"%*s%s %s%s ;\n",prn_ndn,spc_sng,cdl_typ_nm(var_typ),var_trv->nm,dmn_sng);
+  if(prn_flg->cdl){
+    nm_cdl=nm2sng_cdl(var_trv->nm);
+    (void)fprintf(stdout,"%*s%s %s%s ;\n",prn_ndn,spc_sng,cdl_typ_nm(var_typ),nm_cdl,dmn_sng);
+    nm_cdl=(char *)nco_free(nm_cdl);
+  } /* !cdl */
   if(prn_flg->xml) (void)fprintf(stdout,"%s>\n",dmn_sng);
 
   /* Print dimension sizes and names */
@@ -999,7 +1023,7 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
       unsigned long cnk_sz_lon=(unsigned long)cnk_sz[dmn_idx];
 
       /* Coordinate dimension */
-      if(var_trv->var_dmn[dmn_idx].is_crd_var == True ){
+      if(var_trv->var_dmn[dmn_idx].is_crd_var){
 
         crd_sct *crd=var_trv->var_dmn[dmn_idx].crd;
 
@@ -1015,14 +1039,14 @@ nco_prn_var_dfn                     /* [fnc] Print variable metadata */
         (void)fprintf(stdout,"%soordinate is %s)",(CRR_DMN_IS_REC_IN_INPUT[dmn_idx]) ? "Record c" : "C",(!strcmp(crd->crd_grp_nm_fll,var_trv->grp_nm_fll)) ? crd->nm : crd->crd_nm_fll);
 
         /* Non-coordinate dimension */
-      }else if(var_trv->var_dmn[dmn_idx].is_crd_var == False){
+      }else if(!var_trv->var_dmn[dmn_idx].is_crd_var){
 
         dmn_trv_sct *dmn_trv=var_trv->var_dmn[dmn_idx].ncd;
 
         /* NOTE: Use hyperslabbed sizes for dimension size */
         if(srg_typ == NC_CHUNKED){
           (void)fprintf(stdout,"%*s%s dimension %i: %s, size = %li, chunksize = %lu (",prn_ndn,spc_sng,var_trv->nm,dmn_idx,(!strcmp(dmn_trv->grp_nm_fll,var_trv->grp_nm_fll)) ? dmn_trv->nm : dmn_trv->nm_fll,dmn_trv->lmt_msa.dmn_cnt,cnk_sz_lon);
-        }else {
+        }else{
           (void)fprintf(stdout,"%*s%s dimension %i: %s, size = %li (",prn_ndn,spc_sng,var_trv->nm,dmn_idx,(!strcmp(dmn_trv->grp_nm_fll,var_trv->grp_nm_fll)) ? dmn_trv->nm : dmn_trv->nm_fll,dmn_trv->lmt_msa.dmn_cnt);
         }
         (void)fprintf(stdout,"%son-coordinate dimension)",(CRR_DMN_IS_REC_IN_INPUT[dmn_idx]) ? "Record n" : "N");
@@ -1079,8 +1103,10 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
   const char spc_sng[]=""; /* [sng] Space string */
 
   char *dlm_sng=NULL;                        /* [sng] User-specified delimiter string, if any */
+  char *nm_cdl;
   char *unit_sng;                            /* [sng] Units string */ 
   char *sng_val_sng;                         /* [sng] String of NC_CHAR */
+  char *sng_val_sng_cpy; /* [sng] Copy of sng_val_sng to avoid cppcheck error about using sng_val_sng as both parameter and desitnation in sprintf(). NB: free() only one of these two pointers. */
   char val_sng[NCO_ATM_SNG_LNG];
   char var_sng[NCO_MAX_LEN_FMT_SNG];         /* [sng] Variable string */
   char mss_val_sng[]="_"; /* [sng] Print this instead of numerical missing value */
@@ -1172,11 +1198,9 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
     if(prn_flg->md5->dgs) (void)nco_md5_chk(prn_flg->md5,var_nm,var.sz*nco_typ_lng(var.type),grp_id,(long *)NULL,(long *)NULL,var.val.vp);
 
   /* Warn if variable is packed */
-  if(dbg_lvl_get() > 0) {
-    if(nco_pck_dsk_inq(grp_id,&var)){
+  if(dbg_lvl_get() > 0)
+    if(nco_pck_dsk_inq(grp_id,&var))
       (void)fprintf(stderr,"%s: WARNING will print packed values of variable \"%s\". Unpack first (with ncpdq -U) to see actual values.\n",prg_nm_get(),var_nm);
-    }
-  }
 
   /* Refresh number of attributes and missing value attribute, if any */
   var.has_mss_val=nco_mss_val_get(var.nc_id,&var);
@@ -1234,7 +1258,7 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
 
   } /* end if dlm_sng */
 
-  if(prn_flg->cdl){
+  if(prn_flg->cdl || prn_flg->xml){
     char fmt_sng[NCO_MAX_LEN_FMT_SNG];
     dmn_trv_sct *dmn_trv; /* [sct] Unique dimension object */
     int cpd_rec_dmn_idx[NC_MAX_DIMS]; /* [idx] Indices of non-leading record dimensions */
@@ -1242,8 +1266,15 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
     long chr_idx;
     nco_bool is_compound; /* [flg] Variable is compound (has non-leading record dimension) */
     nco_bool cpd_rec_dmn[NC_MAX_DIMS]; /* [flg] Dimension is compound */
-    (void)sprintf(fmt_sng,"%s",nco_typ_fmt_sng_var_cdl(var.type));
-    (void)fprintf(stdout,"%*s%s = ",prn_ndn,spc_sng,var_nm);
+    char * (*chr2sng_sf)(const char chr_val, /* I [chr] Character to process */
+			  char * const val_sng); /* I/O [sng] String to stuff printable result into */
+    if(prn_flg->cdl) chr2sng_sf=chr2sng_cdl; else chr2sng_sf=chr2sng_xml;
+    if(prn_flg->cdl) (void)sprintf(fmt_sng,"%s",nco_typ_fmt_sng_var_cdl(var.type));
+    if(prn_flg->xml) (void)sprintf(fmt_sng,"%s",nco_typ_fmt_sng_att_xml(var.type));
+    nm_cdl=nm2sng_cdl(var_nm);
+    if(prn_flg->xml) (void)fprintf(stdout,"%*s<values>",prn_ndn+prn_flg->var_fst,spc_sng);
+    if(prn_flg->cdl) (void)fprintf(stdout,"%*s%s = ",prn_ndn,spc_sng,nm_cdl);
+    nm_cdl=(char *)nco_free(nm_cdl);
     var_szm1=var.sz-1L;
     is_compound=nco_prn_cpd_chk(var_trv,trv_tbl);
 
@@ -1294,7 +1325,7 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
           chr_val=var.val.cp[lmn];
           if(var.nbr_dim == 0){
             (void)fprintf(stdout,"\"");
-            if(chr_val != '\0') (void)fprintf(stdout,"%s",chr2sng_cdl(chr_val,val_sng));
+            if(chr_val != '\0') (void)fprintf(stdout,"%s",(*chr2sng_sf)(chr_val,val_sng));
             (void)fprintf(stdout,"\"");
             val_sng[0]='\0';
           }else{ /* var.nbr_dim > 0 */
@@ -1304,15 +1335,15 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
               sng_lng=lmt_msa[var.nbr_dim-1]->dmn_cnt;
               sng_lngm1=sng_lng-1UL;
               /* Worst case is printable strings are four times longer than unformatted, i.e. '\\' == "\\\\" */
-              sng_val_sng=(char *)nco_malloc(4*sng_lng+1UL);
+              sng_val_sng_cpy=sng_val_sng=(char *)nco_malloc(4*sng_lng+1UL);
             } /* endif first element of string array */
             /* New string begins each element where penultimate dimension changes */
             if(lmn%sng_lng == 0L){
               (void)fprintf(stdout,"\"");
               sng_val_sng[0]='\0';
             } /* endif new string */
-            (void)strcat(sng_val_sng,chr2sng_cdl(chr_val,val_sng));
-            if(chr_val == '\n' && lmn != var_szm1) (void)sprintf(sng_val_sng,"%s\",\n%*s\"",sng_val_sng,prn_ndn+prn_flg->var_fst,spc_sng);
+            if(chr_val != '\0') (void)fprintf(stdout,"%s",(*chr2sng_sf)(chr_val,val_sng));
+            if(chr_val == '\n' && lmn != var_szm1) (void)sprintf(sng_val_sng,"%s\",\n%*s\"",sng_val_sng_cpy,prn_ndn+prn_flg->var_fst,spc_sng);
             if(lmn%sng_lng == sng_lngm1){
               (void)fprintf(stdout,"%s\"",sng_val_sng);
               /* Print commas after non-final strings */
@@ -1338,7 +1369,7 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
           for(chr_idx=0;chr_idx<sng_lng;chr_idx++){
             val_sng[0]='\0';
             chr_val=sng_val[chr_idx];
-            (void)strcat(sng_val_sng,chr2sng_cdl(chr_val,val_sng));
+	    (void)strcat(sng_val_sng,(*chr2sng_sf)(chr_val,val_sng));
           } /* end loop over character */
           (void)fprintf(stdout,"%s%s",sng_val_sng,(prn_flg->xml) ? "" : "\"");
           /* Print commas after non-final strings */
@@ -1351,9 +1382,10 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
       if(var.type != NC_CHAR && var.type != NC_STRING) (void)fprintf(stdout,"%s%s",val_sng,(lmn != var_szm1) ? cma_sng : "");
     } /* end loop over element */
     rcd_prn+=0; /* CEWI */
-    (void)fprintf(stdout," ;\n");
+    if(prn_flg->cdl) (void)fprintf(stdout," ;\n");
+    if(prn_flg->xml) (void)fprintf(stdout,"</values>\n");
 
-  } /* end if prn_flg->cdl */
+  } /* end if prn_flg->cdl || prn_flg->xml */
 
   if(prn_flg->PRN_DMN_UNITS){
     const char units_nm[]="units"; /* [sng] Name of units attribute */
@@ -1375,7 +1407,7 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
     } /* end if */
   } /* end if PRN_DMN_UNITS */
 
-  if(var.nbr_dim == 0 && !dlm_sng && !prn_flg->cdl){
+  if(var.nbr_dim == 0 && !dlm_sng && !prn_flg->cdl && !prn_flg->xml){
     /* Variable is scalar, byte, or character */
     lmn=0L;
     if(prn_flg->PRN_MSS_VAL_BLANK) is_mss_val = var.has_mss_val ? !memcmp(var.val.vp,var.mss_val.vp,(size_t)val_sz_byt) : False; 
@@ -1433,7 +1465,7 @@ nco_prn_var_val_trv /* [fnc] Print variable data (GTT version) */
     } /* !is_mss_val */
   } /* end if variable is scalar, byte, or character */
 
-  if(var.nbr_dim > 0 && !dlm_sng && !prn_flg->cdl){
+  if(var.nbr_dim > 0 && !dlm_sng && !prn_flg->cdl && !prn_flg->xml){
 
     /* Create mod_map_in */
     for(int idx=0;idx<var.nbr_dim;idx++) mod_map_in[idx]=1L;
@@ -1701,7 +1733,7 @@ lbl_chr_prn:
   if(var.nbr_dim > 0){
     (void)nco_lmt_msa_free(var_trv->nbr_dmn,lmt_msa);
     lmt=(lmt_sct **)nco_free(lmt);
-  }
+  } /* endif */
 
 } /* end nco_prn_var_val_trv() */
 
@@ -1714,12 +1746,13 @@ nco_grp_prn /* [fnc] Recursively print group contents */
 {
   /* Purpose: Recursively print group contents
      Assumptions: 
-     1. Input group name is valid, extracted group (as defined in nco_xtr_dfn()). 
+     1. Input group name is a valid group to be extracted (set in nco_xtr_dfn()). 
         Hence no need to check for group type, or if group is extracted.
      2. Input ID is netCDF file ID, not extracted group ID */
 
   /* Testing: 
-     ncks -5 ~/nco/data/in_grp.nc */
+     ncks -5 ~/nco/data/in_grp.nc
+     ncks --cdl ~/nco/data/in_grp.nc */
 
   const char sls_sng[]="/";        /* [sng] Slash string */
   const char spc_sng[]="";        /* [sng] Space string */
@@ -1727,6 +1760,7 @@ nco_grp_prn /* [fnc] Recursively print group contents */
   char grp_nm[NC_MAX_NAME+1L];      /* [sng] Group name */
   char var_nm[NC_MAX_NAME+1L];      /* [sng] Variable name */ 
 
+  char *nm_cdl;
   char *var_nm_fll;                /* [sng] Full path for variable */
 
   int *grp_ids;                    /* [ID] Sub-group IDs array */  
@@ -1796,9 +1830,15 @@ nco_grp_prn /* [fnc] Recursively print group contents */
   if(dmn_nbr > 1) dmn_lst=nco_lst_srt_nm_id(dmn_lst,dmn_nbr,prn_flg->ALPHA_BY_STUB_GROUP);
 
   if(prn_flg->xml){
-    if(grp_dpt == 0) (void)fprintf(stdout,"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<netcdf xmlns=\"http://www.unidata.ucar.edu/namespaces/netcdf/ncml-2.2\" location=\"%s\">\n",prn_flg->fl_in);
+    if(grp_dpt == 0){
+      if(prn_flg->xml_lcn) (void)fprintf(stdout,"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<netcdf xmlns=\"http://www.unidata.ucar.edu/namespaces/netcdf/ncml-2.2\" location=\"%s\">\n",prn_flg->fl_in); else (void)fprintf(stdout,"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<netcdf xmlns=\"http://www.unidata.ucar.edu/namespaces/netcdf/ncml-2.2\">\n");
+    }else{ /* grp_dpt != 0 */
+      (void)fprintf(stdout,"%*s<group name=\"%s\">\n",grp_dpt*prn_flg->spc_per_lvl,spc_sng,trv_tbl->lst[obj_idx].nm_fll);
+    } /* grp_dpt != 0 */
   }else{ /* !xml */
-    if(grp_dpt == 0 && prn_flg->cdl) (void)fprintf(stdout,"netcdf %s {",prn_flg->fl_stb); else (void)fprintf(stdout,"%*sgroup: %s {",grp_dpt*prn_flg->spc_per_lvl,spc_sng,nco_gpe_evl_stb(prn_flg->gpe,trv_tbl->lst[obj_idx].nm_fll));
+    nm_cdl=nm2sng_cdl(nco_gpe_evl_stb(prn_flg->gpe,trv_tbl->lst[obj_idx].nm_fll));
+    if(grp_dpt == 0 && prn_flg->cdl) (void)fprintf(stdout,"netcdf %s {",prn_flg->fl_stb); else (void)fprintf(stdout,"%*sgroup: %s {",grp_dpt*prn_flg->spc_per_lvl,spc_sng,nm_cdl);
+    nm_cdl=(char *)nco_free(nm_cdl);
     if(prn_flg->fll_pth) (void)fprintf(stdout," // fullname: %s\n",nco_gpe_evl(prn_flg->gpe,grp_nm_fll)); else (void)fprintf(stdout,"\n");
     if(grp_dpt == 0 && prn_flg->nfo_cdl) (void)fprintf(stdout,"%*s// %s",prn_flg->sxn_fst,spc_sng,prn_flg->smr_sng);
     if(grp_dpt == 0 && prn_flg->nfo_cdl) (void)fprintf(stdout,"%*s// ncgen -k netCDF-4 -b -o %s.nc %s.cdl\n",prn_flg->sxn_fst,spc_sng,prn_flg->fl_stb,prn_flg->fl_stb);
@@ -1810,9 +1850,11 @@ nco_grp_prn /* [fnc] Recursively print group contents */
   prn_ndn+=prn_flg->var_fst;
   for(dmn_idx=0;dmn_idx<dmn_nbr;dmn_idx++){
     if(prn_flg->xml){
-      (void)fprintf(stdout,"%*s<dimension name=\"%s\" length=\"%lu\" />\n",prn_ndn,spc_sng,dmn_lst[dmn_idx].nm,(unsigned long)trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].lmt_msa.dmn_cnt);
+      (void)fprintf(stdout,"%*s<dimension name=\"%s\" length=\"%lu\" %s/>\n",prn_ndn,spc_sng,dmn_lst[dmn_idx].nm,(unsigned long)trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].lmt_msa.dmn_cnt,trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].is_rec_dmn ? "isUnlimited=\"true\" " : "");
     }else{ /* !XML */
-      if(trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].is_rec_dmn) (void)fprintf(stdout,"%*s%s = UNLIMITED%s// (%lu currently)\n",prn_ndn,spc_sng,dmn_lst[dmn_idx].nm,(prn_flg->cdl) ? " ; " : " ",(unsigned long)trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].lmt_msa.dmn_cnt); else (void)fprintf(stdout,"%*s%s = %lu%s\n",prn_ndn,spc_sng,dmn_lst[dmn_idx].nm,(unsigned long)trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].lmt_msa.dmn_cnt,(prn_flg->cdl) ? " ;" : "");
+      nm_cdl=nm2sng_cdl(dmn_lst[dmn_idx].nm);
+      if(trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].is_rec_dmn) (void)fprintf(stdout,"%*s%s = UNLIMITED%s// (%lu currently)\n",prn_ndn,spc_sng,nm_cdl,(prn_flg->cdl) ? " ; " : " ",(unsigned long)trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].lmt_msa.dmn_cnt); else (void)fprintf(stdout,"%*s%s = %lu%s\n",prn_ndn,spc_sng,nm_cdl,(unsigned long)trv_tbl->lst_dmn[dmn_lst[dmn_idx].id].lmt_msa.dmn_cnt,(prn_flg->cdl) ? " ;" : "");
+      nm_cdl=(char *)nco_free(nm_cdl);
     } /* !XML */
   } /* end loop over dimension */
 
@@ -1849,7 +1891,7 @@ nco_grp_prn /* [fnc] Recursively print group contents */
     /* Is variable to be extracted? */
     if(trv_tbl->lst[obj_idx].flg_xtr){
       /* NB: ID here is actually index into trv_tbl->lst. It is NOT an ID. 
-	 However, it is same type (int) as an ID so we can use nm_id infrastructure. */
+	 However, it is same type (int) as an ID so we re-use nm_id infrastructure */
       var_lst[var_nbr_xtr].id=obj_idx;
       var_lst[var_nbr_xtr].nm=strdup(var_nm);
       var_nbr_xtr++;
@@ -1875,7 +1917,7 @@ nco_grp_prn /* [fnc] Recursively print group contents */
     if(var_trv.grp_dpt > 0 && prn_flg->fll_pth && prn_flg->trd) (void)fprintf(stdout,"%*s%s\n",prn_flg->ndn,spc_sng,var_trv.nm_fll);
 
     /* Print variable metadata */ 
-    if(prn_flg->PRN_VAR_METADATA || prn_flg->cdl) (void)nco_prn_var_dfn(nc_id,prn_flg,&var_trv);
+    if(prn_flg->PRN_VAR_METADATA || prn_flg->cdl || prn_flg->xml) (void)nco_prn_var_dfn(nc_id,prn_flg,&var_trv);
 
     /* Obtain variable ID using group ID */
     (void)nco_inq_varid(grp_id,var_trv.nm,&var_id);
@@ -1883,7 +1925,10 @@ nco_grp_prn /* [fnc] Recursively print group contents */
     /* Print variable attributes */
     if(var_trv.nbr_att > 0 && prn_flg->PRN_VAR_METADATA) (void)nco_prn_att(grp_id,prn_flg,var_id);
 
-    if(prn_flg->xml) (void)fprintf(stdout,"%*s</variable>\n",prn_ndn,spc_sng);
+    if(prn_flg->xml && prn_flg->PRN_VAR_DATA){
+      (void)nco_prn_var_val_trv(nc_id,prn_flg,&trv_tbl->lst[var_lst[var_idx].id],trv_tbl);
+      (void)fprintf(stdout,"%*s</variable>\n",prn_ndn,spc_sng);
+    } /* !prn_flg->xml */
 
     if(var_idx != var_nbr_xtr-1 && !prn_flg->xml) (void)fprintf(stdout,"\n");
   } /* end loop over var_idx */
@@ -1893,10 +1938,9 @@ nco_grp_prn /* [fnc] Recursively print group contents */
   if(nbr_att > 0 && prn_flg->PRN_GLB_METADATA) nco_prn_att(grp_id,prn_flg,NC_GLOBAL);
 
   /* Print data for group */
-  if(var_nbr_xtr > 0 && prn_flg->PRN_VAR_DATA){
+  if(var_nbr_xtr > 0 && prn_flg->PRN_VAR_DATA && !prn_flg->xml){
     (void)fprintf(stdout,"\n%*sdata:\n",prn_flg->ndn,spc_sng);
-    for(var_idx=0;var_idx<var_nbr_xtr;var_idx++) 
-      (void)nco_prn_var_val_trv(nc_id,prn_flg,&trv_tbl->lst[var_lst[var_idx].id],trv_tbl);
+    for(var_idx=0;var_idx<var_nbr_xtr;var_idx++) (void)nco_prn_var_val_trv(nc_id,prn_flg,&trv_tbl->lst[var_lst[var_idx].id],trv_tbl);
   } /* end if */
 
   /* Variable list no longer needed */
@@ -1939,7 +1983,9 @@ nco_grp_prn /* [fnc] Recursively print group contents */
     sub_grp_nm_fll=(char *)nco_free(sub_grp_nm_fll);
   } /* end loop over grp_idx */
 
-  if(prn_flg->xml && grp_dpt == 0) (void)fprintf(stdout,"</netcdf>\n"); else (void)fprintf(stdout,"%*s} // group %s\n",grp_dpt*prn_flg->spc_per_lvl,spc_sng,(grp_dpt == 0) ? grp_nm_fll : nco_gpe_evl(prn_flg->gpe,grp_nm_fll));
+  if(prn_flg->xml && grp_dpt == 0) (void)fprintf(stdout,"</netcdf>\n"); 
+  if(prn_flg->xml && grp_dpt != 0) (void)fprintf(stdout,"%*s</group>\n",grp_dpt*prn_flg->spc_per_lvl,spc_sng); 
+  if(prn_flg->cdl) (void)fprintf(stdout,"%*s} // group %s\n",grp_dpt*prn_flg->spc_per_lvl,spc_sng,(grp_dpt == 0) ? grp_nm_fll : nco_gpe_evl(prn_flg->gpe,grp_nm_fll));
 
   return rcd;
 } /* end nco_grp_prn() */
@@ -1950,19 +1996,19 @@ nco_prn_cpd_chk                     /* [fnc] Check whether variable is compound
  const trv_tbl_sct * const trv_tbl) /* I [sct] GTT (Group Traversal Table) */ 
 {
   /* Purpose: Check whether variable dimensionality is compound, i.e.,
-  whether variable needs extra printed braces in CDL output.
-  For purposes of this routine, a variable is compound iff it contains
-  a record dimension as any but the leading dimension. */
-
+     whether variable needs extra printed braces in CDL output.
+     For purposes of this routine, a variable is compound iff it contains
+     a record dimension as any but the leading dimension. */
+  
   int dmn_idx;
   dmn_trv_sct *dmn_trv; /* [sct] Unique dimension object */
-
+  
   if(var_trv->nbr_dmn <= 1) return False;
-
+  
   for(dmn_idx=1;dmn_idx<var_trv->nbr_dmn;dmn_idx++){ /* NB: dimension index starts at 1 */
     dmn_trv=nco_dmn_trv_sct(var_trv->var_dmn[dmn_idx].dmn_id,trv_tbl); 
     if(dmn_trv->is_rec_dmn) break; /* fxm: change to var_dmn->is_rec_var */
   } /* end loop over dimensions */
-
+  
   if(dmn_idx != var_trv->nbr_dmn) return True; else return False;
 } /* end nco_prn_cpd_chk() */
