@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.59 2013/08/28 01:51:01 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_sng_utl.c,v 1.65 2013/10/16 03:27:26 zender Exp $ */
 
 /* Purpose: String utilities */
 
@@ -28,14 +28,14 @@ strcasecmp /* [fnc] Lexicographical case-insensitive string comparison */
 #ifndef _MSC_VER
       sng_1_c=(char *)free(sng_1_c);
       sng_2_c=(char *)free(sng_2_c);
-#endif
+#endif /* _MSC_VER */
       return -1;
     }
     if(chr_1 > chr_2){
 #ifndef _MSC_VER
       sng_1_c=(char *)free(sng_1_c);
       sng_2_c=(char *)free(sng_2_c);
-#endif
+#endif /* _MSC_VER */
       return 1;
     }
     if(chr_1 == 0){
@@ -155,12 +155,116 @@ sng_idx_dlm_c2f /* [fnc] Replace brackets with parentheses in a string */
   } /* end while */
 } /* end sng_idx_dlm_c2f() */
 
+char * /* O [sng] CDL-compatible name */
+nm2sng_cdl /* [fnc] Turn variable/dimension/attribute name into legal CDL */
+(const char * const nm_sng) /* I [sng] Name to CDL-ize */
+{
+  /* Purpose: Turn variable/dimension/attribute name into legal CDL 
+     Currently this means protecting special characters with backslash so ncgen can read them
+     NB: Calling function must free() memory containing CDL-ized string
+     Weird file menagerie shows that:
+     NASA HDF4 TRMM files (3B43*.HDF) have filenames starting with numerals (and no metadata)
+     NASA HDF4 AIRS files (AIRS*.hdf) have colons in dimension names
+     NASA HDF4 AMSR_E files (AMSR_E*.hdf) have spaces in variable names, colons and spaces in dimension names
+     NASA HDF4 MODIS files (MOD*.hdf) have colons in names
+     NASA HDF4 MOPPITT files (MOP*.hdf) have spaces in variable names, colons and spaces in dimension names */
+
+  /* https://www.unidata.ucar.edu/software/netcdf/docs/netcdf/CDL-Syntax.html:
+     "In CDL, most special characters are escaped with a backslash '\' character, but that character is not actually part of the netCDF name. The special characters that do not need to be escaped in CDL names are underscore '_', period '.', plus '+', hyphen '-', or at sign '@'. */
+
+  char *chr_in_ptr; /* [sng] Pointer to current character in input name */
+  char *chr_out_ptr; /* [sng] Pointer to current character in output name */
+  char *nm_cdl; /* [sng] CDL-compatible name */
+  char *nm_cpy; /* [sng] Copy of input */
+
+  int nm_lng; /* [nbr] Length of original name */
+  
+  if(nm_sng == NULL) return NULL;
+
+  /* Otherwise name contains special character(s)... */
+  nm_lng=strlen(nm_sng);
+  /* Maximum conceivable length of CDL-ized name */
+  chr_out_ptr=nm_cdl=(char *)nco_malloc(4*nm_lng+1L);
+  /* Copy to preserve const-ness */
+  chr_in_ptr=nm_cpy=(char *)strdup(nm_sng);
+  /* NUL-terminate in case input string is empty so will be output string */
+  chr_out_ptr[0]='0';
+
+  /* Search and replace special characters */
+
+  /* This block stolen from: ncdump/utils.c/escaped_name() */ 
+
+  if((*chr_in_ptr >= 0x01 && *chr_in_ptr <= 0x20) || (*chr_in_ptr == 0x7f)){
+    (void)fprintf(stderr,"%s: ERROR name begins with space or control-character: %c\n",prg_nm_get(),*chr_in_ptr);
+    nco_exit(EXIT_FAILURE);
+  } /* endif error */
+
+  /* Special case: leading number allowed, but we must escape it for CDL */
+  if((*chr_in_ptr >= '0' && *chr_in_ptr <= '9')) *chr_out_ptr++ = '\\';
+
+  while(*chr_in_ptr){
+    if(isascii(*chr_in_ptr)){
+      if(iscntrl(*chr_in_ptr)){	/* Render control chars as two hex digits, \%xx */
+	snprintf(chr_out_ptr,4,"\\%%%.2x",*chr_in_ptr);
+	chr_out_ptr+=4;
+      }else{
+	switch(*chr_in_ptr){
+	case ' ':
+	case '!':
+	case '"':
+	case '#':
+	case '$':
+	case '&':
+	case '\'':
+	case '(':
+	case ')':
+	case '*':
+	case ',':
+	case ':':
+	case ';':
+	case '<':
+	case '=':
+	case '>':
+	case '?':
+	case '[':
+	case ']':
+	case '\\':
+	case '^':
+	case '`':
+	case '{':
+	case '|':
+	case '}':
+	case '~':
+	  *chr_out_ptr++='\\';
+	  *chr_out_ptr++=*chr_in_ptr;
+	  break;
+	default: /* NB: includes '/' */
+	  *chr_out_ptr++=*chr_in_ptr;
+	  break;
+	} /* end switch */
+      } /* not a control character */
+    }else{ /* not ascii, assume just UTF-8 byte */
+      *chr_out_ptr++=*chr_in_ptr;
+    } /* end else not ascii */
+    /* Advance character */
+    chr_in_ptr++;
+  } /* end while loop */
+  /* NUL-terminate */
+  *chr_out_ptr=0;
+
+  /* Free memory */
+  nm_cpy=(char *)nco_free(nm_cpy);
+
+  return nm_cdl;
+} /* end nm2sng_cdl */
+
 char * /* O [sng] String containing printable result */
 chr2sng_cdl /* [fnc] Translate C language character to printable, visible ASCII bytes */
 (const char chr_val, /* I [chr] Character to process */
  char * const val_sng) /* I/O [sng] String to stuff printable result into */
 {
-  /* Purpose: Translate character to C-printable, visible ASCII bytes for CDL */
+  /* Purpose: Translate character to C-printable, visible ASCII bytes for CDL
+     Reference: netcdf-c/ncdump/ncdump.c:pr_att_string() */
   
   switch(chr_val){              /* man ascii:Oct   Dec   Hex   Char \X  */
   case '\a': strcpy(val_sng,"\\a"); break; /* 007   7     07    BEL '\a' Bell */
@@ -188,8 +292,12 @@ chr2sng_xml /* [fnc] Translate C language character to printable, visible ASCII
 (const char chr_val, /* I [chr] Character to process */
  char * const val_sng) /* I/O [sng] String to stuff printable result into */
 {
-  /* Purpose: Translate character to C-printable, visible ASCII bytes for XML */
+  /* Purpose: Translate character to C-printable, visible ASCII bytes for XML
+     Reference: netcdf-c/ncdump/ncdump.c:pr_attx_string() 
+     NB: Unclear whether and'ing with octal 0377 helps anything */
+  //  unsigned char uchar;
   
+  //  switch(uchar=chr_val & 0377){              /* man ascii:Oct   Dec   Hex   Char \X  */
   switch(chr_val){              /* man ascii:Oct   Dec   Hex   Char \X  */
   case '\n': strcpy(val_sng,"&#xA;"); break; /* 012   10    0A    LF  '\n' Linefeed */
   case '\r': strcpy(val_sng,"&#xD;"); break; /* 015   13    0D    CR  '\r' Carriage return */
@@ -198,10 +306,11 @@ chr2sng_xml /* [fnc] Translate C language character to printable, visible ASCII
   case '>': strcpy(val_sng,"&gt;"); break;
   case '&': strcpy(val_sng,"&amp;"); break;
   case '\"': strcpy(val_sng,"&quot;"); break;
-  case '\0':	
+  case '\0': /* NB: Unidata handles NUL differently */
     break;
   default: 
-    sprintf(val_sng,"%c",chr_val); break;
+    //    if(iscntrl(uchar)) sprintf(val_sng,"&#%d;",uchar); else sprintf(val_sng,"%c",uchar);
+    if(iscntrl(chr_val)) sprintf(val_sng,"&#%d;",chr_val); else sprintf(val_sng,"%c",chr_val);
     break;
   } /* end switch */
 
@@ -301,9 +410,9 @@ sng_trm_trl_zro /* [fnc] Trim zeros trailing the decimal point from floating poi
   /* Purpose: Trim zeros trailing decimal point from floating point string
      Allow trl_zro_max trailing zeros to remain */
 
-  char *trl_zro_ptr; /* [sng] */
-  char *dcm_ptr; /* [sng] */
-  char *vld_ptr=NULL; /* [sng] */
+  char *trl_zro_ptr; /* [sng] Trailing zero pointer */
+  char *dcm_ptr; /* [sng] Decimal point pointer */
+  char *vld_ptr=NULL; /* [sng] Valid pointer */
   char chr_val; /* [chr] Character value */
 
   int cnt_zro_rmn; /* [nbr] Number of trailing zeros remaining until maximum reached */
