@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_avg.h,v 1.24 2012/01/01 20:51:53 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_avg.h,v 1.26 2013/07/16 18:39:43 zender Exp $ */
 
 /* Purpose: Average variables */
 
-/* Copyright (C) 1995--2012 Charlie Zender
+/* Copyright (C) 1995--2013 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -23,6 +23,9 @@
 #include "nco.h" /* netCDF Operator (NCO) definitions */
 #include "nco_cnf_typ.h" /* Conform variable types */
 #include "nco_mmr.h" /* Memory management */
+#ifdef _MSC_VER
+# include "nco_rth_flt.h" /* Float-precision arithmetic, MSVC macros */
+#endif /* !_MSC_VER */
 #include "nco_rth_utl.h" /* Arithmetic controls and utilities */
 #include "nco_var_rth.h" /* Variable arithmetic */
 #include "nco_var_utl.h" /* Variable utilities */
