@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.154 2013/08/27 19:40:46 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_var_lst.c,v 1.156 2013/10/05 07:36:30 zender Exp $ */
 
 /* Purpose: Variable list utilities */
 
@@ -841,7 +841,6 @@ nco_var_lst_mrg /* [fnc] Merge two variable lists into same order */
   return rcd;
 } /* end nco_var_lst_mrg() */
 
-
 void
 nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
 (var_sct * const * const var, /* I [sct] Variable list (input file) */
@@ -899,16 +898,17 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
     var_op_typ[idx]=prc_typ;
     var_nm=var[idx]->nm;
     var_typ=var[idx]->type;
-    if((var_typ == NC_BYTE) || (var_typ == NC_UBYTE) || (var_typ == NC_CHAR) || (var_typ == NC_STRING)) var_typ_fnk=True; else var_typ_fnk=False;
+    /* Until 20131005, NCO default was to consider NC_BYTE and NC_UBYTE as funky, too */
+    if((var_typ == NC_CHAR) || (var_typ == NC_STRING)) var_typ_fnk=True; else var_typ_fnk=False;
 
     /* Many operators should not process coordinate variables, or auxiliary coordinate variables (lat, lon, time, latixy, longxy, ...) and bounds (lat_bnds, lon_bnds, ...)
-    20130112: As of today set is_crd_var true in nco_var_fll() when either of these conditions is true 
-    so no longer need to specify these conditions separately. 
-    Keep this old code here as a reminder that is_crd_var also incorporates these conditions
-    is_spc_in_crd_att=nco_is_spc_in_crd_att(var[idx]->nc_id,var[idx]->id);
-    is_spc_in_bnd_att=nco_is_spc_in_bnd_att(var[idx]->nc_id,var[idx]->id); */
+       20130112: As of today set is_crd_var true in nco_var_fll() when either of these conditions is true 
+       so no longer need to specify these conditions separately. 
+       Keep this old code here as a reminder that is_crd_var also incorporates these conditions
+       is_spc_in_crd_att=nco_is_spc_in_crd_att(var[idx]->nc_id,var[idx]->id);
+       is_spc_in_bnd_att=nco_is_spc_in_bnd_att(var[idx]->nc_id,var[idx]->id); */
 
-    /* Override operation type based depending on variable properties and program */
+    /* Override operation type depending on variable properties and program */
     switch(prg_id){
     case ncap:
       var_op_typ[idx]=fix_typ;
@@ -945,36 +945,34 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
     case ncwa:
       if(nco_pck_plc != nco_pck_plc_nil){
         /* Packing operation requested
-        Variables are processed for packing/unpacking operator unless... */
+	   Variables are processed for packing/unpacking operator unless... */
         if(
-          /* ...packing coordinate variables has few benefits... */
-          (var[idx]->is_crd_var && !(nco_pck_plc == nco_pck_plc_upk) ) ||
-          /* unless if it's NOT a record variable and the policy is unpack 
-          20120711. nco: ncpdq unpack coordinate variables */     
-          /* ...unpacking requested for unpacked variable... */
-          (nco_pck_plc == nco_pck_plc_upk && !var[idx]->pck_ram) ||
-          /* ...or packing unpacked requested and variable is already packed... */
-          (nco_pck_plc == nco_pck_plc_all_xst_att && var[idx]->pck_ram) ||
-          /* ...or re-packing packed requested and variable is unpacked... */
-          (nco_pck_plc == nco_pck_plc_xst_new_att && !var[idx]->pck_ram) ||
-          /* ...or... */
-          (
-          /* ...any type of packing requested... */
-          (nco_pck_plc == nco_pck_plc_all_new_att || 
-          nco_pck_plc == nco_pck_plc_all_xst_att || 
-          nco_pck_plc == nco_pck_plc_xst_new_att) &&
-          /* ...yet map does not allow (re-)packing... */
-          !nco_pck_plc_typ_get(nco_pck_map,var[idx]->typ_upk,(nc_type *)NULL)
-          )
-          )
+	   /* ...packing coordinate variables has few benefits... */
+	   (var[idx]->is_crd_var && !(nco_pck_plc == nco_pck_plc_upk) ) ||
+	   /* unless if it's NOT a record variable and the policy is unpack 
+	      20120711. nco: ncpdq unpack coordinate variables */     
+	   /* ...unpacking requested for unpacked variable... */
+	   (nco_pck_plc == nco_pck_plc_upk && !var[idx]->pck_ram) ||
+	   /* ...or packing unpacked requested and variable is already packed... */
+	   (nco_pck_plc == nco_pck_plc_all_xst_att && var[idx]->pck_ram) ||
+	   /* ...or re-packing packed requested and variable is unpacked... */
+	   (nco_pck_plc == nco_pck_plc_xst_new_att && !var[idx]->pck_ram) ||
+	   /* ...or... */
+	   (
+	    /* ...any type of packing requested... */
+	    (nco_pck_plc == nco_pck_plc_all_new_att || 
+	     nco_pck_plc == nco_pck_plc_all_xst_att || 
+	     nco_pck_plc == nco_pck_plc_xst_new_att) &&
+	    /* ...yet map does not allow (re-)packing... */
+	    !nco_pck_plc_typ_get(nco_pck_map,var[idx]->typ_upk,(nc_type *)NULL)
+	    )
+	   )
           var_op_typ[idx]=fix_typ;
       }else{ /* endif packing operation requested */
         /* Process every variable containing an altered (averaged, re-ordered, reversed) dimension */
         for(idx_dmn=0;idx_dmn<var[idx]->nbr_dim;idx_dmn++){
           for(idx_xcl=0;idx_xcl<nbr_dmn_xcl;idx_xcl++){
-            if(var[idx]->dim[idx_dmn]->id == dmn_xcl[idx_xcl]->id){
-              break;
-            }
+            if(var[idx]->dim[idx_dmn]->id == dmn_xcl[idx_xcl]->id) break;
           } /* end loop over idx_xcl */
           if(idx_xcl != nbr_dmn_xcl){
             var_op_typ[idx]=prc_typ;
@@ -982,9 +980,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
           } /* end if */
         } /* end loop over idx_dmn */
         /* Fix variables with no altered (averaged, re-ordered, reversed) dimensions */
-        if(idx_dmn == var[idx]->nbr_dim){
-          var_op_typ[idx]=fix_typ;
-        }
+        if(idx_dmn == var[idx]->nbr_dim) var_op_typ[idx]=fix_typ;
       } /* endif averaging or re-ordering */
       break;
     default: nco_dfl_case_prg_id_err(); break;
@@ -992,40 +988,39 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
 
     /* Previous case-statement does not account for variables with no data */
     if(nco_is_rth_opr(prg_id))
-      if(var[idx]->sz == 0L)
-        var_op_typ[idx]=fix_typ;
+      if(var[idx]->sz == 0L) var_op_typ[idx]=fix_typ;
 
     if(CNV_CCM_CCSM_CF){
       if(!strcmp(var_nm,"ntrm") || !strcmp(var_nm,"ntrn") || !strcmp(var_nm,"ntrk") || !strcmp(var_nm,"ndbase") || !strcmp(var_nm,"nsbase") || !strcmp(var_nm,"nbdate") || !strcmp(var_nm,"nbsec") || !strcmp(var_nm,"mdt") || !strcmp(var_nm,"mhisf")) var_op_typ[idx]=fix_typ;
       /* NB: all !strcmp()'s except "msk_" which uses strstr() */
       if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"hyam") || !strcmp(var_nm,"hybm") || !strcmp(var_nm,"hyai") || !strcmp(var_nm,"hybi") || !strcmp(var_nm,"gw") || !strcmp(var_nm,"lon_bnds") || !strcmp(var_nm,"lat_bnds") || !strcmp(var_nm,"area") || !strcmp(var_nm,"ORO") || !strcmp(var_nm,"date") || !strcmp(var_nm,"datesec") || (strstr(var_nm,"msk_") == var_nm))) var_op_typ[idx]=fix_typ;
       /* Known "multi-dimensional coordinates" in CCSM-like model output:
-      lat, lon, lev are normally 1-D coordinates
-      Known exceptions:
-      lat and lon are "2-D coordinates" in NARCCAP output
-      NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
-      latixy and longxy are "2-D coordinates" in CLM output
-      CLM does not specify latixy and longxy in "coordinates" attribute of any fields
-      NARCCAP output gives all "coordinate-like" fields an "axis" attribute
-      This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
-      CLM does not give an "axis" attribute to any fields
-      One method of chasing down all "coordinate-like" fields is to look
-      for the field name in the "coordinates" attribute of any variable.
-      However, this will miss (false-negative) the case when no variables 
-      use an N-D coordinate-like variable as a coordinate. 
-      And this may hit (false-positive) the record coordinate (often "time")
-      which should be averaged by ncra, though perhaps not by ncea.
-      "coordinate-like" variables that should be "fixed", and not
-      differenced, interpolated, or ensemble-averaged, include those 
-      satisfying these conditions:
-      0. Traditional coordinate (1-D variable same name as its dimension)
-      1. Present in a "coordinates" attribute (except "time" for ncra)
-      2. Present in a "bounds" attribute (except "time_bnds" for ncra)
-      3. Contain an "axis" attribute (except "time") fxm not done yet
-      4. Found in empirical list of variables
-      NB: In the above algorithm discussion, "time" is my shorthand 
-      for "the record variable, if any" */
-
+	 lat, lon, lev are normally 1-D coordinates
+	 Known exceptions:
+	 lat and lon are "2-D coordinates" in NARCCAP output
+	 NARCCAP specifies lat and lon in "coordinates" attribute of 2-D fields
+	 latixy and longxy are "2-D coordinates" in CLM output
+	 CLM does not specify latixy and longxy in "coordinates" attribute of any fields
+	 NARCCAP output gives all "coordinate-like" fields an "axis" attribute
+	 This includes the record coordinate (i.e., "time") which both ncra and ncwa _should_ process
+	 CLM does not give an "axis" attribute to any fields
+	 One method of chasing down all "coordinate-like" fields is to look
+	 for the field name in the "coordinates" attribute of any variable.
+	 However, this will miss (false-negative) the case when no variables 
+	 use an N-D coordinate-like variable as a coordinate. 
+	 And this may hit (false-positive) the record coordinate (often "time")
+	 which should be averaged by ncra, though perhaps not by ncea.
+	 "coordinate-like" variables that should be "fixed", and not
+	 differenced, interpolated, or ensemble-averaged, include those 
+	 satisfying these conditions:
+	 0. Traditional coordinate (1-D variable same name as its dimension)
+	 1. Present in a "coordinates" attribute (except "time" for ncra)
+	 2. Present in a "bounds" attribute (except "time_bnds" for ncra)
+	 3. Contain an "axis" attribute (except "time") fxm not done yet
+	 4. Found in empirical list of variables
+	 NB: In the above algorithm discussion, "time" is my shorthand 
+	 for "the record variable, if any" */
+      
       /* Conditions #1 and #2 are already implemented above in the case() statement */
       /* Check condition #4 above: */
       if(is_sz_rnk_prv_rth_opr && (!strcmp(var_nm,"lat") || !strcmp(var_nm,"lon") || !strcmp(var_nm,"lev") || !strcmp(var_nm,"longxy") || !strcmp(var_nm,"latixy") )) var_op_typ[idx]=fix_typ;
@@ -1073,16 +1068,16 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
       /* Do nothing */
       break;
     case ncbo:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_BYTE, NC_UBYTE, NC_CHAR, or NC_STRING in order to perform a binary operation (e.g., subtraction)\n",prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_CHAR, or NC_STRING in order to perform a binary operation (e.g., subtraction)\n",prg_nm_get());
       break;
     case ncea:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_BYTE, NC_UBYTE, NC_CHAR, or NC_STRING\n",prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable that is not NC_CHAR, or NC_STRING\n",prg_nm_get());
       break;
     case ncecat:
       (void)fprintf(stdout,"%s: HINT Extraction list must contain a non-coordinate variable\n",prg_nm_get());
       break;
     case ncflint:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a variable that is not NC_BYTE, NC_UBYTE, NC_CHAR, or NC_STRING\n",prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a variable that is not NC_CHAR, or NC_STRING\n",prg_nm_get());
       break;
     case ncks:
       /* Do nothing */
@@ -1091,7 +1086,7 @@ nco_var_lst_dvd /* [fnc] Divide input lists into output lists */
       (void)fprintf(stdout,"%s: HINT Extraction list must contain a variable that shares at least one dimension with the re-order list\n",prg_nm_get());
       break;
     case ncra:
-      (void)fprintf(stdout,"%s: HINT Extraction list must contain a record variable that is not NC_BYTE, NC_UBYTE, NC_CHAR, or NC_STRING\n",prg_nm_get());
+      (void)fprintf(stdout,"%s: HINT Extraction list must contain a record variable that is not NC_CHAR, or NC_STRING\n",prg_nm_get());
       break;
     case ncrcat:
       (void)fprintf(stdout,"%s: HINT Extraction list must contain a record variable which to concatenate\n",prg_nm_get());
@@ -1146,14 +1141,15 @@ nco_var_lst_dvd_trv                          /* [fnc] Divide input lists into ou
   var_op_typ=prc_typ;
   var_nm=var->nm;
   var_typ=var->type;
-  if((var_typ == NC_BYTE) || (var_typ == NC_UBYTE) || (var_typ == NC_CHAR) || (var_typ == NC_STRING)) var_typ_fnk=True; else var_typ_fnk=False;
+  /* Until 20131005, NCO default was to consider NC_BYTE and NC_UBYTE as funky, too */
+  if((var_typ == NC_CHAR) || (var_typ == NC_STRING)) var_typ_fnk=True; else var_typ_fnk=False;
 
   /* Many operators should not process coordinate variables, or auxiliary coordinate variables (lat, lon, time, latixy, longxy, ...) and bounds (lat_bnds, lon_bnds, ...)
-  20130112: As of today set is_crd_var true in nco_var_fll() when either of these conditions is true 
-  so no longer need to specify these conditions separately. 
-  Keep this old code here as a reminder that is_crd_var also incorporates these conditions
-  is_spc_in_crd_att=nco_is_spc_in_crd_att(var[idx]->nc_id,var[idx]->id);
-  is_spc_in_bnd_att=nco_is_spc_in_bnd_att(var[idx]->nc_id,var[idx]->id); */
+     20130112: As of today set is_crd_var true in nco_var_fll() when either of these conditions is true 
+     so no longer need to specify these conditions separately. 
+     Keep this old code here as a reminder that is_crd_var also incorporates these conditions
+     is_spc_in_crd_att=nco_is_spc_in_crd_att(var[idx]->nc_id,var[idx]->id);
+     is_spc_in_bnd_att=nco_is_spc_in_bnd_att(var[idx]->nc_id,var[idx]->id); */
 
   /* Override operation type based depending on variable properties and program */
   switch(prg_id){
